bayespy.inference.vmp.nodes.gaussian.WrapToGaussianWishart.lower_bound_contribution
===================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: WrapToGaussianWishart.lower_bound_contribution